Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
__init__.py | 0 | 0 | 0 | 100%
admin.py | 101 | 4 | 0 | 96%
apps.py | 10 | 0 | 0 | 100%
boot_django.py | 15 | 1 | 0 | 93%
conftest.py | 2 | 0 | 0 | 100%
default_settings.py | 1 | 0 | 0 | 100%
tests/__init__.py | 0 | 0 | 0 | 100%
tests/test_custom_admin_pages.py | 146 | 1 | 0 | 99%
tests/test_urls.py | 3 | 0 | 0 | 100%
urls.py | 15 | 1 | 0 | 93%
views/__init__.py | 1 | 0 | 0 | 100%
views/admin_base_view.py | 44 | 15 | 0 | 66%
/home/lkjos/projects/django-custom-admin-pages/test_proj/test_app/__init__.py | 0 | 0 | 0 | 100%
/home/lkjos/projects/django-custom-admin-pages/test_proj/test_app/admin.py | 5 | 0 | 0 | 100%
/home/lkjos/projects/django-custom-admin-pages/test_proj/test_app/apps.py | 4 | 0 | 0 | 100%
/home/lkjos/projects/django-custom-admin-pages/test_proj/test_app/migrations/0001_initial.py | 5 | 0 | 0 | 100%
/home/lkjos/projects/django-custom-admin-pages/test_proj/test_app/migrations/__init__.py | 0 | 0 | 0 | 100%
/home/lkjos/projects/django-custom-admin-pages/test_proj/test_app/models.py | 3 | 0 | 0 | 100%
Total | 355 | 22 | 0 | 94%

No items found using the specified filter.